@@ -22,7 +22,7 @@
 #define ABSTRACTTOKENIZER_H
 
 #include <QtCore/QString>
-#include <sonnet/sonnetcore_export.h>
+#include "sonnetcore_export.h"
 
 namespace Sonnet
 {
@@ -100,11 +100,11 @@ public:
     WordTokenizer(const QString& buffer=QString());
     ~WordTokenizer();
 
-    void setBuffer(const QString& buffer);
-    bool hasNext() const;
-    QStringRef next();
-    QString buffer() const;
-    void replace(int position, int len, const QString& newWord);
+    void setBuffer(const QString& buffer) Q_DECL_OVERRIDE;
+    bool hasNext() const Q_DECL_OVERRIDE;
+    QStringRef next() Q_DECL_OVERRIDE;
+    QString buffer() const Q_DECL_OVERRIDE;
+    void replace(int position, int len, const QString& newWord) Q_DECL_OVERRIDE;
     
     /** Returns true if this word should be spell checked. This ignores email addresses, URLs and other things according to configuration */
     bool isSpellcheckable() const;
@@ -127,11 +127,11 @@ class SONNETCORE_EXPORT SentenceTokenizer : public AbstractTokenizer
 public:
     SentenceTokenizer(const QString& buffer=QString());
     ~SentenceTokenizer();
-    void setBuffer(const QString& buffer);
-    bool hasNext() const;
-    QStringRef next();
-    QString buffer() const;
-    void replace(int position, int len, const QString& newWord);
+    void setBuffer(const QString& buffer) Q_DECL_OVERRIDE;
+    bool hasNext() const Q_DECL_OVERRIDE;
+    QStringRef next() Q_DECL_OVERRIDE;
+    QString buffer() const Q_DECL_OVERRIDE;
+    void replace(int position, int len, const QString& newWord) Q_DECL_OVERRIDE;
 private:
     BreakTokenizerPrivate* const d;
 };
